
***************
Getting started
***************

Overview
========

This package provides an API for accessing various properties of elements from
the periodic table of elements. 


The repository is hosted on `bitbucket <https://bitbucket.org/lukaszmentel/mendeleev>`_.

Contributing
============

All contributions are welcome!

If you would like to suggest an improvement or report a bug or data inconsistency please consider creating an
`issue on bitbucket <https://bitbucket.org/lukaszmentel/mendeleev/issues>`_.
I would be especially grateful for references to possible data updates and sources and recommendations of new data.


Citing
======

If you use *mendeleev* in a scientific publication, please consider citing the software as

|    L. M. Mentel, *mendeleev* - A Python resource for properties of chemical elements, ions and isotopes. , 2014-- . Available at: `https://bitbucket.org/lukaszmentel/mendeleev <https://bitbucket.org/lukaszmentel/mendeleev>`_.



Here's the reference in the `BibLaTeX <https://www.ctan.org/pkg/biblatex?lang=en>`_ format

.. code-block:: latex

   @software{mendeleev2014,
      author = {Mentel, Łukasz},
      title = {{mendeleev} -- A Python resource for properties of chemical elements, ions and isotopes},
      url = {https://bitbucket.org/lukaszmentel/mendeleev},
      version = {0.3.6},
      date = {2014--},
  }

or the older `BibTeX <http://www.bibtex.org/>`_ format

.. code-block:: latex

   @misc{mendeleev2014,
      auhor = {Mentel, Łukasz},
      title = {mendeleev} -- A Python resource for properties of chemical elements, ions and isotopes, ver. 0.3.6},
      howpublished = {\url{https://bitbucket.org/lukaszmentel/mendeleev}},
      year  = {2014--},
   }


Related projects
================

`periodictable <https://github.com/pkienzle/periodictable>`_
    This package provides a periodic table of the elements with support for mass, density and xray/neutron scattering information.

`periodic <https://github.com/luisnaranjo733/periodic>`_
    Periodic is an open source simple python API/command line script for the periodic table.

Funding
=======

This project is supported by the RCN (The Research Council of Norway) project
number 239193.